.. include:: ../README.rst

Changelog
==========

.. include:: ../CHANGELOG.rst

API documention
================

.. automodule:: swab
        :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

